@@ -22,12 +22,43 @@ JINJA2_EXTENSIONS = getattr(settings, 'JINJA2_EXTENSIONS', [])
 JINJA2_FILTERS = getattr(settings, 'JINJA2_FILTERS', {})
 JINJA2_TESTS = getattr(settings, 'JINJA2_TESTS', {})
 JINJA2_GLOBALS = getattr(settings, 'JINJA2_GLOBALS', {})
+JINJA2_AUTOESCAPE = getattr(settings, 'JINJA2_AUTOESCAPE', False)
 
-from django_jinja.builtins import filters
 from django_jinja import builtins
 
 JINJA2_FILTERS.update({
     'reverse': builtins.filters.reverse,
+    'addslashes': builtins.filters.addslashes,
+    'escapejs': builtins.filters.escapejs_filter,
+    'capfirst': builtins.filters.capfirst,
+    'floatformat': builtins.filters.floatformat,
+    'truncatechars': builtins.filters.truncatechars,
+    'truncatewords': builtins.filters.truncatewords,
+    'truncatewords_html': builtins.filters.truncatewords_html,
+    'wordwrap': builtins.filters.wordwrap,
+    'title': builtins.filters.title,
+    'slugify': builtins.filters.slugify,
+    'lower': builtins.filters.lower,
+    'ljust': builtins.filters.ljust,
+    'rjust': builtins.filters.rjust,
+    'linebreaksbr': builtins.filters.linebreaksbr,
+    'linebreaks': builtins.filters.linebreaks_filter,
+    'removetags': builtins.filters.removetags,
+    'striptags': builtins.filters.striptags,
+    'join': builtins.filters.join,
+    'random': builtins.filters.random,
+    'add': builtins.filters.add,
+    'date': builtins.filters.date,
+    'time': builtins.filters.time,
+    'timesince': builtins.filters.timesince_filter,
+    'timeuntil': builtins.filters.timeuntil_filter,
+    'default': builtins.filters.default,
+    'default_if_none': builtins.filters.default_if_none,
+    'divisibleby': builtins.filters.divisibleby,
+    'yesno': builtins.filters.yesno,
+    'filesizeformat': builtins.filters.filesizeformat,
+    'pprint': builtins.filters.pprint,
+    'safe': builtins.filters.safe,
 })
 
 JINJA2_GLOBALS.update({
@@ -129,6 +160,14 @@ class Environment(Environment):
 
             if reg_attr.tests:
                 self.tests.update(reg_attr.tests)
+            
+            if reg_attr.globals:
+                self.globals.update(reg_attr.globals)
+        
+
+        # Add builtin extensions.
+        self.add_extension(builtins.extensions.CsrfExtension)
+        #self.add_extension(builtins.extensions.LoadExtension)
 
 
 class Library(object):
@@ -138,12 +177,12 @@ class Library(object):
         self.globals = {}
         self.tests = {}
 
-    def tag(self, func,name=None):
+    def tag(self, func, name=None):
         if name == None:
             name = getattr(func, "_decorated_function", func).__name__
         self.globals[name] = func
 
-    def filter(self, func,name=None):
+    def filter(self, func, name=None):
         if name == None:
             name = getattr(func, "_decorated_function", func).__name__
         self.filters[name] = func
@@ -154,15 +193,16 @@ class Library(object):
     def global_context(self, func, name=None):
         if name == None:
             name = getattr(func, "_decorated_function", func).__name__
+        
         self.globals[name] = func
 
-    def set(self,*args,**kwargs):
+    def set(self, *args, **kwargs):
         for k in kwargs.keys(): #is a object with a name
             self[k] = kwargs[k]
         for a in args:
             self.tag(a) #is a function
 
-    def inclusion_tag(self,template,func,takes_context=False):
+    def inclusion_tag(self, template, func, takes_context=False):
         if takes_context:
             import jinja2
             @jinja2.contextfunction
@@ -186,9 +226,9 @@ class Library(object):
 
 
 initial_params = {
-    'autoescape': False,
+    'autoescape': JINJA2_AUTOESCAPE,
     'loader': FileSystemLoader(app_directories.app_template_dirs + settings.TEMPLATE_DIRS),
-    'extensions':['jinja2.ext.i18n'] + JINJA2_EXTENSIONS,
+    'extensions':['jinja2.ext.i18n', 'jinja2.ext.autoescape'],
 }
 
 initial_params.update(JINJA2_ENVIRONMENT_OPTIONS)
